@@ -38,7 +38,6 @@ static QString decodeUrl( const QString &input );
 PageViewWidget::PageViewWidget( QWidget* parent )
   : QTextBrowser( parent ),
     chm_(  new Chm() ),
-    tableOfContents_(),
     baseUrl_("/"),
     page_(0)
 {
@@ -56,9 +55,9 @@ PageViewWidget::~PageViewWidget()
 
 void PageViewWidget::openPageNum( size_t page )
 {
-  if ( page && page < static_cast<size_t>(tableOfContents_.size()) )
+  if ( page && page < static_cast<size_t>(chm_->getToc().size()) )
   {
-    QString url = tableOfContents_[page].urls.join("|");
+    QString url = chm_->getToc()[page].urls.join("|");
     
     //MainWindow* wnd = dynamic_cast<MainWindow*>(parentWidget()); 
     //if ( wnd )
@@ -158,19 +157,17 @@ bool PageViewWidget::loadChmFile( const QString& filename )
 
     filename_ = filename;
 
-    tableOfContents_.clear(); 
-    chm_->parseTableOfContents( &tableOfContents_ );
+    const ChmEntryList& toc = chm_->getToc();
 
-
-    if ( tableOfContents_.size()  )
+    if ( toc.size()  )
     {
       MainWindow* wnd = dynamic_cast<MainWindow*>(parentWidget()); 
       if ( wnd )
       {
-        wnd->setWindowTitle( QString(tableOfContents_[0].name) );
+        wnd->setWindowTitle( toc[0].name );
       }
 
-      openPage( tableOfContents_[0].urls.join("|") );
+      openPage( toc[0].urls.join("|") );
     }
 
   }
@@ -314,9 +311,10 @@ void PageViewWidget::zoomIn()
 
 void PageViewWidget::bookmarkCurrentPage()
 {
-  if ( tableOfContents_.size() )
+  const ChmEntryList& toc = chm_->getToc();
+  if ( toc.size() )
   {
-    QString url = tableOfContents_[page_].urls.join("|");
+    QString url = toc[page_].urls.join("|");
     chm_->bookmarkPage( url );
   }
 }
